@@ -38,7 +38,6 @@ from django.http import (
     )
 from django.shortcuts import render_to_response, redirect, get_object_or_404
 from django.template import RequestContext, loader
-from django.utils.html import escape
 from django.utils.safestring import mark_safe
 from django.views.generic.list_detail import object_list, object_detail
 
@@ -61,7 +60,6 @@ from dashboard_app.models import (
     Test,
     TestResult,
     TestRun,
-    TestingEffort,
 )
 
 
@@ -640,32 +638,6 @@ def data_view_detail(request, name):
         }, RequestContext(request))
 
 
-@BreadCrumb("Tests", parent=index)
-def test_list(request):
-    return object_list(
-        request,
-        queryset=Test.objects.all(),
-        template_name="dashboard_app/test_list.html",
-        template_object_name="test",
-        extra_context={
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(test_list)
-        })
-
-
-@BreadCrumb("Details of {test_id}", parent=test_list, needs=['test_id'])
-def test_detail(request, test_id):
-    return object_detail(
-        request,
-        queryset=Test.objects.all(),
-        slug=test_id,
-        slug_field="test_id",
-        template_name="dashboard_app/test_detail.html",
-        template_object_name="test",
-        extra_context={
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(test_detail, test_id=test_id)
-        })
-
-
 def redirect_to(request, object, trailing):
     url = object.get_absolute_url() + trailing
     qs = request.META.get('QUERY_STRING')
@@ -701,127 +673,3 @@ def redirect_to_bundle(request, content_sha1, trailing=''):
         request.user,
         content_sha1=content_sha1)
     return redirect_to(request, bundle, trailing)
-
-
-@BreadCrumb("Testing efforts", parent=index)
-def testing_effort_list(request):
-    return render_to_response(
-        "dashboard_app/testing_effort_list.html", {
-            'effort_list': TestingEffort.objects.all(
-            ).order_by('name'),
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(
-                testing_effort_list),
-        }, RequestContext(request))
-
-
-@BreadCrumb(
-    "{effort}",
-    parent=testing_effort_list,
-    needs=["pk"])
-def testing_effort_detail(request, pk):
-    effort = get_object_or_404(TestingEffort, pk=pk)
-    return render_to_response(
-        "dashboard_app/testing_effort_detail.html", {
-            'effort': effort,
-            'belongs_to_user': effort.project.is_owned_by(request.user),
-            'test_run_list': effort.get_test_runs(
-            ).select_related(
-                'denormalization',
-                'bundle',
-                'bundle__bundle_stream',
-                'test',
-            ),
-            'bread_crumb_trail': BreadCrumbTrail.leading_to(
-                testing_effort_detail,
-                effort=effort,
-                pk=pk),
-        }, RequestContext(request))
-
-
-from lava_projects.models import Project
-from lava_projects.views import project_detail
-from dashboard_app.forms import TestingEffortForm
-
-
-@BreadCrumb(
-    "Start a new test effort",
-    parent=project_detail,
-    needs=["project_identifier"])
-@login_required
-def testing_effort_create(request, project_identifier):
-    project = get_object_or_404(Project, identifier=project_identifier)
-    if request.method == 'POST':
-        form = TestingEffortForm(request.POST)
-        # Check the form
-        if form.is_valid():
-            # And make a project instance
-            effort = TestingEffort.objects.create(
-                name=form.cleaned_data['name'],
-                description=form.cleaned_data['description'],
-                project=project)
-            # Create all the required tags
-            effort.tags = [
-                Tag.objects.get_or_create(name=tag_name)[0]
-                for tag_name in re.split("[, ]+", form.cleaned_data["tags"])
-                if tag_name != ""]
-            return HttpResponseRedirect(effort.get_absolute_url())
-    else:
-        form = TestingEffortForm()
-    # Render to template
-    template_name = "dashboard_app/testing_effort_form.html"
-    t = loader.get_template(template_name)
-    c = RequestContext(request, {
-        'form': form,
-        'bread_crumb_trail': BreadCrumbTrail.leading_to(
-            testing_effort_create,
-            project=project,
-            project_identifier=project.identifier)
-    })
-    return HttpResponse(t.render(c))
-
-
-@BreadCrumb(
-    "Update",
-    parent=testing_effort_detail,
-    needs=["pk"])
-@login_required
-def testing_effort_update(request, pk):
-    try:
-        effort = TestingEffort.objects.get(pk=pk)
-    except TestingEffort.DoesNotExist:
-        raise Http404()
-    if not effort.project.is_owned_by(request.user):
-        return HttpResponse("not allowed")
-    if request.method == 'POST':
-        form = TestingEffortForm(request.POST)
-        # Check the form
-        if form.is_valid():
-            # And update the effort object
-            effort.name=form.cleaned_data['name']
-            effort.description=form.cleaned_data['description']
-            # As well as tags
-            effort.tags = [
-                Tag.objects.get_or_create(name=tag_name)[0]
-                for tag_name in re.split("[, ]+", form.cleaned_data["tags"])
-                if tag_name != ""]
-            # Save the changes
-            effort.save()
-            return HttpResponseRedirect(effort.get_absolute_url())
-    else:
-        form = TestingEffortForm(initial={
-            'name': effort.name,
-            'description': effort.description,
-            'tags': " ".join([tag.name for tag in effort.tags.order_by('name').all()])
-        })
-    # Render to template
-    template_name = "dashboard_app/testing_effort_form.html"
-    t = loader.get_template(template_name)
-    c = RequestContext(request, {
-        'form': form,
-        'effort': effort,
-        'bread_crumb_trail': BreadCrumbTrail.leading_to(
-            testing_effort_update,
-            effort=effort,
-            pk=effort.pk)
-    })
-    return HttpResponse(t.render(c))
